import { registerObjectClass } from "./ObjectClassMap";
import { DataStream } from "./DataStream";
import { FieldDesc } from "./FieldDesc";
declare enum ClassDescFlags {
    WriteMethod = 1,
    Serializable = 2,
    Externalizable = 4,
    BlockData = 8,
    Enum = 16
}
interface JavaClassDescInfo {
    flags: ClassDescFlags;
    fields: FieldDesc[];
    annotations: (AnyJavaObject | DataStream)[];
    superClassDesc: JavaClassDesc | null;
}
interface JavaClassDesc extends JavaClassDescInfo {
    className: string;
    serialVersionUid: bigint;
}
interface JavaEnum {
    classDesc: JavaClassDesc;
    enumConstantName: string;
}
export declare class JavaObject {
    readonly className: string;
    readonly serialVersionUid: bigint;
    readonly fields: Map<string, any>;
    readonly annotations: (AnyJavaObject | DataStream)[];
    constructor(classDesc: JavaClassDesc);
}
type AnyJavaObject = any | string | JavaEnum | JavaClassDesc | null | AnyJavaType[];
type AnyJavaType = string | number | bigint | boolean | AnyJavaObject;
export declare class JavaObjectStream {
    static RegisterObjectClass: typeof registerObjectClass;
    private readonly stream;
    private readonly handles;
    constructor(file: Uint8Array);
    next(): any;
    read(): Generator<any, void, unknown>;
    readObjectFields(fields: FieldDesc[]): Map<string, any>;
    private newHandle;
    private readType;
    private readString;
    private readContent;
    private readObject;
    private readObjectWithType;
    private readNewClass;
    private readClassDesc;
    private readClassDescWithType;
    private readNewClassDesc;
    private readClassDescInfo;
    private readAnnotations;
    private readFieldDesc;
    private readNewArray;
    private readNewObject;
    private readFromTypeCode;
    private readBlockData;
    private readNewString;
    private readNewEnum;
    private readPrevObject;
    private readNullReference;
    private readException;
    private readReset;
}
export {};
